@@ -4,7 +4,7 @@
  * This file is part of libgta, a library that implements the Generic Tagged
  * Array (GTA) file format.
  *
- * Copyright (C) 2010, 2011
+ * Copyright (C) 2010, 2011, 2012
  * Martin Lambers <marlam@marlam.de>
  *
  * Libgta is free software: you can redistribute it and/or modify it under the
@@ -61,16 +61,16 @@
  * \section examples Examples
  *
  * Examples written in C:
- * - <a href="example-basic.c.html">Introductory example</a>
- * - <a href="example-tags.c.html">Using tags</a>
- * - <a href="example-stream-io.c.html">Stream-based input/output</a>
- * - <a href="example-block-io.c.html">Block-based input/output</a>
+ * - <a href="example-basic_8c.html">Introductory example</a>
+ * - <a href="example-tags_8c.html">Using tags</a>
+ * - <a href="example-stream-io_8c.html">Stream-based input/output</a>
+ * - <a href="example-block-io_8c.html">Block-based input/output</a>
  *
  * Examples written in C++:
- * - <a href="example-basic.cpp.html">Introductory example</a>
- * - <a href="example-tags.cpp.html">Using tags</a>
- * - <a href="example-stream-io.cpp.html">Stream-based input/output</a>
- * - <a href="example-block-io.cpp.html">Block-based input/output</a>
+ * - <a href="example-basic_8cpp.html">Introductory example</a>
+ * - <a href="example-tags_8cpp.html">Using tags</a>
+ * - <a href="example-stream-io_8cpp.html">Stream-based input/output</a>
+ * - <a href="example-block-io_8cpp.html">Block-based input/output</a>
  *
  * \page example-basic.c Examples written in C: Introductory example
  * \include example-basic.c
@@ -97,8 +97,8 @@
 
 #include <stdio.h>
 
-#ifdef _MSC_VER
-/* MSVC lacks the C99 header <stdint.h> */
+#if defined _MSC_VER && _MSC_VER < 1600
+/* MSVC versions older than Visual Studio 2010 lack the C99 header <stdint.h> */
 typedef signed __int64 intmax_t;
 typedef unsigned __int64 uintmax_t;
 #   ifdef _WIN64
